package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.FeedbackFile;

import java.util.List;

/**
 * 反馈附件Mapper接口
 * 
 * @author ruoyi
 * @date 2022-10-21
 */
public interface FeedbackFileMapper 
{
    /**
     * 查询反馈附件
     * 
     * @param fileId 反馈附件ID
     * @return 反馈附件
     */
    public FeedbackFile selectFeedbackFileById(Long fileId);

    /**
     * 查询反馈附件列表
     * 
     * @param feedbackFile 反馈附件
     * @return 反馈附件集合
     */
    public List<FeedbackFile> selectFeedbackFileList(FeedbackFile feedbackFile);

    /**
     * 新增反馈附件
     * 
     * @param feedbackFile 反馈附件
     * @return 结果
     */
    public int insertFeedbackFile(FeedbackFile feedbackFile);

    /**
     * 修改反馈附件
     * 
     * @param feedbackFile 反馈附件
     * @return 结果
     */
    public int updateFeedbackFile(FeedbackFile feedbackFile);

    /**
     * 删除反馈附件
     * 
     * @param fileId 反馈附件ID
     * @return 结果
     */
    public int deleteFeedbackFileById(Long fileId);

    /**
     * 批量删除反馈附件
     * 
     * @param fileIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteFeedbackFileByIds(String[] fileIds);

    public int batchFileInfo(List<FeedbackFile> list);
}
